@@ -1,10 +1,10 @@
 package POE::Component::IKC::ClientLite;
 
 ############################################################
-# $Id: ClientLite.pm 312 2007-11-29 21:24:42Z fil $
+# $Id: ClientLite.pm 468 2009-05-01 17:01:00Z fil $
 # By Philp Gwyn <fil@pied.nu>
 #
-# Copyright 1999,2002,2004 Philip Gwyn.  All rights reserved.
+# Copyright 1999-2009 Philip Gwyn.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -25,7 +25,7 @@ use Carp;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_client);
-$VERSION = '0.2000';
+$VERSION = '0.2100';
 
 sub DEBUG { 0 }
 
@@ -506,7 +506,7 @@ sub _get_freezer
 
 1;
 
-__DATA__
+__END__
 
 
 =head1 NAME
@@ -664,6 +664,15 @@ this isn't really a kernel.  But hey.
 
 Philip Gwyn, <perl-ikc at pied.nu>
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 1999-2008 by Philip Gwyn.  All rights reserved.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+See L<http://www.perl.com/language/misc/Artistic.html>
+
 =head1 SEE ALSO
 
 L<POE>, L<POE::Component::IKC>
