@@ -1,8 +1,8 @@
 package POE::Component::IKC::Freezer;
 
 ############################################################
-# $Id: Freezer.pm 311 2007-11-29 21:15:53Z fil $
-# Copyright 2001,2002,2004 Philip Gwyn.  All rights reserved.
+# $Id: Freezer.pm 468 2009-05-01 17:01:00Z fil $
+# Copyright 2001-2009 Philip Gwyn.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 
@@ -15,7 +15,7 @@ use Carp;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(freeze thaw dclone);
-$VERSION = '0.2000';
+$VERSION = '0.2100';
 
 sub DEBUG { 0 }
 
@@ -67,6 +67,15 @@ distribution.
 
 Philip Gwyn, <perl-ikc at pied.nu>
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 1999-2008 by Philip Gwyn.  All rights reserved.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+See L<http://www.perl.com/language/misc/Artistic.html>
+
 =head1 SEE ALSO
 
 L<POE>, L<POE::Component::IKC::Client>.
