@@ -1,9 +1,9 @@
-# $Id: Proxy.pm 311 2007-11-29 21:15:53Z fil $
+# $Id: Proxy.pm 468 2009-05-01 17:01:00Z fil $
 package POE::Component::IKC::Proxy;
 
 ##############################################################################
-# $Id: Proxy.pm 311 2007-11-29 21:15:53Z fil $
-# Copyright 1999,2002,2004 Philip Gwyn.  All rights reserved.
+# $Id: Proxy.pm 468 2009-05-01 17:01:00Z fil $
+# Copyright 1999-2009 Philip Gwyn.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -21,7 +21,7 @@ use POE::Component::IKC::Specifier;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_proxy);
-$VERSION = '0.2000';
+$VERSION = '0.2100';
 
 sub DEBUG { 0 }
 
@@ -157,6 +157,15 @@ remote session.  You probably don't want to use it directly.
 
 Philip Gwyn, <perl-ikc at pied.nu>
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 1999-2008 by Philip Gwyn.  All rights reserved.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+See L<http://www.perl.com/language/misc/Artistic.html>
+
 =head1 SEE ALSO
 
 L<POE>, L<POE::Component::IKC>
