@@ -1,9 +1,9 @@
 package POE::Component::IKC::Specifier;
 
 ############################################################
-# $Id: Specifier.pm 311 2007-11-29 21:15:53Z fil $
+# $Id: Specifier.pm 468 2009-05-01 17:01:00Z fil $
 #
-# Copyright 1999,2002,2004 Philip Gwyn.  All rights reserved.
+# Copyright 1999-2009 Philip Gwyn.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -18,7 +18,7 @@ use Carp;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw( specifier_parse specifier_name specifier_part);
-$VERSION = '0.2000';
+$VERSION = '0.2100';
 
 sub DEBUG { 0 }
 
@@ -202,6 +202,15 @@ Turns a specifier into a string.
 
 Philip Gwyn, <perl-ikc at pied.nu>
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 1999-2008 by Philip Gwyn.  All rights reserved.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+See L<http://www.perl.com/language/misc/Artistic.html>
+
 =head1 SEE ALSO
 
 L<POE>, L<POE::Component::IKC::Responder>
